# Chainmock

<a href="https://pypi.org/project/chainmock/">
  <img src="https://img.shields.io/pypi/v/chainmock" alt="pypi">
</a>
<a href="https://github.com/ollipa/chainmock/actions/workflows/ci.yml">
  <img src="https://github.com/ollipa/chainmock/actions/workflows/ci.yml/badge.svg" alt="ci">
</a>
<a href="https://chainmock.readthedocs.io/">
  <img src="https://img.shields.io/readthedocs/chainmock" alt="documentation">
</a>
<a href="./LICENSE">
  <img src="https://img.shields.io/pypi/l/chainmock" alt="license">
</a>

Mocking library for Python and Pytest.

## Documentation

https://chainmock.readthedocs.io/
